PdmConfig

Struct PdmConfig 

pub struct PdmConfig {
    pub tx: Option<PdmTxConfig>,
    pub rx: Option<PdmRxConfig>,
}
PDM mode configuration (simplex TX and/or RX).

Fields

tx: Option<PdmTxConfig>

Optional TX unit configuration.

rx: Option<PdmRxConfig>

Optional RX unit configuration.

Implementations

Source

impl PdmConfig

pub fn tx_only(tx: PdmTxConfig) -> Self

PDM TX only (recommended simplex setup).

pub fn rx_only(rx: PdmRxConfig) -> Self

PDM RX only (recommended simplex setup).

pub fn validate(&self, info: &Info) -> Result<(), PdmError>

Validate that exactly one direction is configured and that the settings are valid for the given I2S instance.